{
    'positive': {
        'required': False,
        'type': 'string'
    },
    'négative': {
        'required': False,
        'type': 'string'
    },
    'erreur': {
        'required': False,
        'type': 'string'
    }
}