{
    'nom': {
        'required': True,
        'type': 'string'
    },
    'entrée': {
        'required': True,
        'type': 'string'
    },
    'sortie': {
        'required': True,
        'type': 'string'
    },
    'rétroactions': {
        'required': False,
        'type': 'dict'
    }
}